##  Essentials
  * Fact sheets only
Virtual workspaces manage access to fact sheets. Diagrams, reports, and update notifications for fact sheets from all workspaces are accessible to all users. Fact sheets in diagrams are visible, even if the virtual workspace restricts access for this user. Clicking on a restricted fact sheet will result in an error for this user.
  * Activation required
Reach out to the support team to enable the feature. If in doubt, check your contract to determine if you already have the virtual workspaces feature. If not, it is always possible to add it through your CSM.
  * Single sign-on (SSO) required
You need to authenticate your users via SSO and also manage roles via your identity provider (IpP).
